`Source code on GitHub <https://github.com/hiddenSymmetries/booz_xform>`_
=========================================================================

The source code for ``simsopt`` can be found at https://github.com/hiddenSymmetries/simsopt.
